'use strict'

exports.launch = launch
exports.createClients = createClients

const util = require('../util')
const influxdb = require('../influxdb')
const Logger = util.getLogger(__filename)

function launch (Context) {
  return new Promise((resolve, reject) => {
    influxdb.launch(Context, (err, proc) => {
      if (err) return reject(err)

      if (Context.usingExternalInflux) {
        Logger.info(`Connected to Influxdb`)
      } else {
        Logger.info(`launched InfluxDB on ${proc.url}`)
        Context.influxdbProcess = proc
      }

      // We're up now, remove the temporary object installed during
      // bootstrap (which is probably the same one, but nevermind that)
      Context.influxdbLaunchingProcess = null

      if (Context.influxdbWriter &&
          Context.influxdbWriter._bufferedWhileStarting) {
        Logger.info(`Writing ${Context.influxdbWriter.queue.length} buffered metrics to InfluxDB.`)
      }
      resolve()
    })
  })
}

function createClients (Context) {
  Context.influxdbReader = influxdb.createReader(Context)
  Context.influxdbWriter = influxdb.createWriter(Context)
}
