'use strict'

exports.handleRequest = handleRequest

const util = require('../../util')
const Logger = util.getLogger(__dirname, __filename)

// Handle the HTTP request
function handleRequest (req, res) {
  const context = req.nsConsole.context
  const qData = req.nsConsole.qData

  const diskAssetManager = context.diskAssetManager
  if (diskAssetManager == null) {
    res.status(501)
    Logger.error('diskAssetManager not initialized')
    return res.send({ error: 'Server error' })
  }

  const asset = diskAssetManager.byId(qData.id)
  const summaryAsset = diskAssetManager.summaryAsset(qData.id)

  if (!asset) {
    res.status(404)
    return res.send({ error: 'Asset not found' })
  }

  diskAssetManager.delete(qData.id)
  // If deleting main asset and have a summary, delete that too
  if (summaryAsset) {
    diskAssetManager.delete(summaryAsset.asset)
  }
  // If deleting summary, delete main asset
  if (asset.snapshotAsset) {
    diskAssetManager.delete(asset.snapshotAsset)
  }

  res.status(200)
  res.send(asset)
}
