'use strict'

exports.handleRequest = handleRequest

const queryExpressions = require('../../query-expressions')

const util = require('../../util')
const Logger = util.getLogger(__dirname, __filename)

// Handle the HTTP request
function handleRequest (req, res) {
  const context = req.nsConsole.context
  const eventStream = req.nsConsole.eventStream
  const id = req.nsConsole.qData.id
  let queryExpr = req.nsConsole.qData.q

  Logger.debug('handling request')

  // get the info
  if (id != null) {
    const agent = context.agentManager.byId(id)
    const normalizedId = agent ? agent.id : id
    try {
      queryExpr = queryExpressions.parse(context, `id=${normalizedId}`)
    } catch (err) {
      eventStream.writeError(null, undefined, `invalid agent id ${id}`)
      eventStream.close()
      return
    }
  }

  const agents = context.agentManager.query(queryExpr)
  for (let agent of agents) {
    const info = Object.assign({}, agent.info)
    info.time = new Date(agent.info.processStart)
    eventStream.writeData(info)
  }

  eventStream.close()
}
