'use strict'

exports.handleRequest = handleRequest

const normalizers = require('./normalizers')

const util = require('../../util')
const Logger = util.getLogger(__dirname, __filename)

// Handle the HTTP request
function handleRequest (req, res) {
  const context = req.nsConsole.context
  const eventStream = req.nsConsole.eventStream
  const queryExpr = req.nsConsole.qData.q

  Logger.debug('handling request')

  const agents = context.agentManager.list()
  for (let agent of agents) {
    if (agent.metrics == null || agent.info == null) continue
    if (queryExpr && !queryExpr.evalForAgent(agent)) continue

    const agentRecord = {
      time: new Date(),
      info: normalizers.agentInfo(agent.info),
      metrics: normalizers.agentInfo(agent.metrics)
    }

    eventStream.writeData(agentRecord)
  }

  eventStream.close()
}
