'use strict'

// functions to normalize data structures

exports.agentInfo = agentInfo
exports.plain = plain

const AgentInfoProps = ['time', 'id', 'app', 'hostname', 'tags']

// normalize metric, info, etc
// idea is to return same object passed in, with properties sorted nicely
function agentInfo (object) {
  const result = {}
  const otherProps = Object.keys(object)
    .filter(prop => AgentInfoProps.indexOf(prop) === -1)
    .sort()

  for (let prop of AgentInfoProps) {
    let val = object[prop]
    if (val == null) {
      switch (prop) {
        case 'time': val = Date.now(); break
        case 'tags': val = []; break
        default: val = ''
      }
    }

    if (prop === 'time' && typeof val === 'number') val = new Date(val)

    result[prop] = val
  }

  for (let prop of otherProps) {
    result[prop] = object[prop]
  }

  return result
}

// normalize by just sorting the property names
function plain (object) {
  const result = {}
  const props = Object.keys(object).sort()

  for (let prop of props) {
    result[prop] = object[prop]
  }

  return result
}

// CLI tester
if (require.main === module) test()

function test () {
  const base = { tags: 5, hostname: 4, app: 3, id: 2, time: 1 }
  const input = [
    Object.assign({}, base, {info: {}, metrics: {}}),
    Object.assign({}, base, {rss: 6, cpu: 7}),
    Object.assign({}, {rss: 6, cpu: 7})
  ]

  for (let data of input) {
    const result = agentInfo(data)
    console.log(`in:  ${JSON.stringify(data)}`)
    console.log(`out: ${JSON.stringify(result)}`)
    console.log('')
  }
}
