'use strict'

const Agent = require('../../agent')
const util = require('../../util')
const Logger = util.getLogger(__dirname, __filename)

module.exports = function (context) {
  const name = 'loop_blocked'
  const endName = 'loop_unblocked'
  function run (messageObj) {
    let agent = context.agentManager.byId(messageObj.agentId)

    if (!agent) {
      agent = Agent.create(context, messageObj.agentId)
      context.agentManager.upsert(agent)
      context.zmqServer.sendConfig(`configuration-${agent.id}`)
    }

    if (!messageObj.body) {
      Logger.warn('Got malformed blocked message.', messageObj, agent)
      return
    }

    if (messageObj.command === 'loop_blocked') {
      var formatted = `Process blocked for ${messageObj.body.blocked_for} ms`

      var count = 0
      for (var frame of messageObj.body.stack) {
        if (frame.is_eval) {
          if (frame.script_name) {
            formatted += `\n    at [eval] (${frame.script_name}:${frame.line_number}:${frame.column})`
          } else {
            formatted += `\n    at [eval]:${frame.line_number}:${frame.column}`
          }
        } else {
          if (frame.function_name) {
            formatted += `\n    at ${frame.function_name} (${frame.script_name}:${frame.line_number}:${frame.column})`
          } else {
            formatted += `\n    at ${frame.script_name}:${frame.line_number}:${frame.column}`
          }
        }

        // Limit notification to 10 frames
        if (++count >= 10) {
          break
        }
      }

      const eventArgs = Agent.getEventArgs(agent)
      eventArgs.threshold = messageObj.body.blocked_for
      eventArgs.loopId = messageObj.body.loop_id
      eventArgs.callbackCntr = messageObj.body.callback_cntr
      eventArgs.stack = formatted
      context.eventManager.emitSystemEvent('process-blocked', agent.id, eventArgs)
    } else {
      const eventArgs = Agent.getEventArgs(agent)
      eventArgs.blockedFor = messageObj.body.blocked_for
      eventArgs.loopId = messageObj.body.loop_id
      eventArgs.callbackCntr = messageObj.body.callback_cntr
      context.eventManager.emitSystemEvent('process-unblocked', agent.id, eventArgs)
    }
  }

  function predicate (messageObj) {
    return (messageObj.command === name || messageObj.command === endName)
  }

  return { name, run, predicate }
}
