# snapdiff

## Addon

A Node.js addon binding has been provided in order to allow instrumenting snapshot aggregation from JavaScript.
Please consult the te

### JS API

```js
const { aggregate } = require('snapdiff')

aggregate({ fullPath: filePath }, onaggregate)

function onaggregate(err, json) {
  if (err) return console.error(err)
  console.log(json)
}
```

_Please review `./lib/snapdiff.js` and the tests for more options._

## CLI

A command line interface _which leverages the addon_ is provided as `snapdiff`.

Therefore after cloning perform the following: `cd snapdiff && npm install -g`.
At this point you will have a global `snapdiff` command which you can leverage as follows:

```
usage: snapdiff <snapshotFile> <snapdiff-options>

  Parses the given heapsnapshot and prints out the aggregated JSON.
  Pipe through [jq](https://stedolan.github.io/jq/) for best results

OPTIONS:

  -t, --type            Snapshot type (json|gzip). If not provided it is deduced from the file extension

  -m, --maxstringlength The maximum amount of constructor name characters to include in the aggregate
  
  -d, --debug           Turn on debugging for diagnostics purposes 

  -h, --help            Print this help message.


EXAMPLES:

  Parse into aggregate with default options

    snapdiff ./path-to/snapshot.heapsnapshot
  
  Parse into aggregate with from gzip file

    snapdiff ./path-to/snapshot.compressed.heapsnapshot -t gzip

  Parse into aggregate limiting constructor string length to 20

    snapdiff ./path-to/snapshot.heapsnapshot -m 20
```

## C++ lib

snapdiff also can be leveraged directly as a C++ library. A Makefile is included. In order to build a `main` file for
testing/debugging please do `make main`. This will add a `main` executable inside `./bin`.

At this poing the flags in the Makefile need to be edited in order to switch from Debug to Release build and vice versa.

## Research

- [snapshot structure](docs/snapshot-structure.md)
- [memory overhead of snapshot processing in order to obtain aggregate](docs/aggregate-overhead.md)
